mutation LoginWithVerificationCodeMutation(
    $verificationCode: String!
    $emailAddress: String
    $phoneNumber: String
) {
    loginWithVerificationCode(
        verificationCode: $verificationCode
        emailAddress: $emailAddress
        phoneNumber: $phoneNumber
    ) {
        status
    }
}
