fragment UserSnippetFragment on PoeUser {
    id
    uid
    bio
    handle
    fullName
    viewerIsFollowing
    isPoeOnlyUser
    profilePhotoURLTiny: profilePhotoUrl(size: tiny)
    profilePhotoURLSmall: profilePhotoUrl(size: small)
    profilePhotoURLMedium: profilePhotoUrl(size: medium)
    profilePhotoURLLarge: profilePhotoUrl(size: large)
    isFollowable
}
