mutation AddHumanMessageMutation(
    $chatId: BigInt!
    $bot: String!
    $query: String!
    $source: MessageSource
    $withChatBreak: Boolean! = false
) {
    messageCreateWithStatus(
        chatId: $chatId
        bot: $bot
        query: $query
        source: $source
        withChatBreak: $withChatBreak
    ) {
        message {
            id
            __typename
            messageId
            text
            linkifiedText
            authorNickname
            state
            vote
            voteReason
            creationTime
            suggestedReplies
            chat {
                id
                shouldShowDisclaimer
            }
        }
        messageLimit{
          canSend
          numMessagesRemaining
          resetTime
          shouldShowReminder
        }
        chatBreak {
            id
            __typename
            messageId
            text
            linkifiedText
            authorNickname
            state
            vote
            voteReason
            creationTime
            suggestedReplies
        }
    }
}
