subscription viewerStateUpdated {
  viewerStateUpdated {
    id
    ...ChatPageBotSwitcher_viewer
  }
}

fragment BotHeader_bot on Bot {
  displayName
  messageLimit {
    dailyLimit
  }
  ...BotImage_bot
}

fragment BotImage_bot on Bot {
  image {
    __typename
    ... on LocalBotImage {
      localName
    }
    ... on UrlBotImage {
      url
    }
  }
  displayName
}

fragment BotLink_bot on Bot {
  displayName
}

fragment ChatPageBotSwitcher_viewer on Viewer {
  availableBots {
    id
    messageLimit {
      dailyLimit
    }
    ...BotLink_bot
    ...BotHeader_bot
  }
  allowUserCreatedBots: booleanGate(gateName: "enable_user_created_bots")
}
